
import { useState, useEffect } from 'react';
import { Link, useLocation } from 'react-router-dom';
import { Menu, X, ChevronDown } from 'lucide-react';
import AuthButton from '@/components/auth/AuthButton';
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu";

const Navigation = () => {
  const [isOpen, setIsOpen] = useState(false);
  const location = useLocation();

  // Close mobile menu when route changes
  useEffect(() => {
    setIsOpen(false);
  }, [location]);

  // Close mobile menu when clicking outside
  useEffect(() => {
    const handleClickOutside = (event: MouseEvent) => {
      const nav = document.getElementById('mobile-menu');
      const button = document.getElementById('mobile-menu-button');
      
      if (nav && button && !nav.contains(event.target as Node) && !button.contains(event.target as Node)) {
        setIsOpen(false);
      }
    };

    if (isOpen) {
      document.addEventListener('mousedown', handleClickOutside);
    }

    return () => {
      document.removeEventListener('mousedown', handleClickOutside);
    };
  }, [isOpen]);

  const handleParentsClick = () => {
    // Always scroll to top when clicking For Parents link
    setTimeout(() => {
      window.scrollTo({ top: 0, behavior: 'smooth' });
    }, 100);
  };

  const handleTeachersClick = () => {
    // Always scroll to top when clicking For Teachers link
    setTimeout(() => {
      window.scrollTo({ top: 0, behavior: 'smooth' });
    }, 100);
  };

const navItems = [
    { href: '/', label: 'Home' },
    { href: '/parents', label: 'For Parents', onClick: handleParentsClick },
    { href: '/teachers', label: 'For Teachers', onClick: handleTeachersClick },
    { href: '/about', label: 'About' },
    { href: '/videos', label: 'Video Resources' },
  ];

  const faqDropdownItems = [
    { href: '/faq', label: 'All FAQ' },
    { href: '/special-education-advocate', label: 'What is a Special Education Advocate?' },
    { href: '/what-is-an-iep', label: 'What Is an IEP?' },
    { href: '/special-education-eligibility', label: 'How Does My Child Qualify for Special Education?' },
  ];
  
  const contactDropdownItems = [
    { href: '/contact', label: 'Parents & Families' },
    { href: '/teachers-contact', label: 'Teachers & School Staff' },
  ];

  return (
    <nav className="bg-white shadow-lg sticky top-0 z-50">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="flex justify-between items-center h-16">
          {/* Logo */}
          <div className="flex-shrink-0">
            <Link to="/" className="text-2xl font-bold text-primary">
              The IEP Coach
            </Link>
          </div>

          {/* Desktop Navigation */}
          <div className="hidden md:block">
            <div className="ml-10 flex items-baseline space-x-4">
              {navItems.map((item) => (
                <Link
                  key={item.href}
                  to={item.href}
                  onClick={item.onClick}
                  className={`px-3 py-2 rounded-md text-sm font-medium transition-colors duration-200 ${
                    location.pathname === item.href
                      ? 'text-accent bg-accent/10'
                      : 'text-gray-700 hover:text-accent hover:bg-accent/5'
                  }`}
                >
                  {item.label}
                </Link>
              ))}
              
              {/* FAQ Dropdown */}
              <DropdownMenu>
                <DropdownMenuTrigger className={`px-3 py-2 rounded-md text-sm font-medium transition-colors duration-200 flex items-center ${
                  location.pathname === '/faq' || location.pathname === '/what-is-an-iep' || location.pathname === '/special-education-eligibility' || location.pathname === '/special-education-advocate'
                    ? 'text-accent bg-accent/10'
                    : 'text-gray-700 hover:text-accent hover:bg-accent/5'
                }`}>
                  FAQ
                  <ChevronDown className="ml-1 h-4 w-4" />
                </DropdownMenuTrigger>
                <DropdownMenuContent className="bg-white border border-gray-200 shadow-lg z-[60] min-w-[250px]">
                  {faqDropdownItems.map((item) => (
                    <DropdownMenuItem key={item.href} asChild>
                      <Link
                        to={item.href}
                        className={`block px-4 py-2 text-sm hover:bg-gray-100 ${
                          location.pathname === item.href
                            ? 'text-accent font-medium'
                            : 'text-gray-700'
                        }`}
                      >
                        {item.label}
                      </Link>
                    </DropdownMenuItem>
                  ))}
                </DropdownMenuContent>
              </DropdownMenu>
              
              {/* Contact Dropdown */}
              <DropdownMenu>
                <DropdownMenuTrigger className={`px-3 py-2 rounded-md text-sm font-medium transition-colors duration-200 flex items-center ${
                  location.pathname === '/contact' || location.pathname === '/teachers-contact'
                    ? 'text-accent bg-accent/10'
                    : 'text-gray-700 hover:text-accent hover:bg-accent/5'
                }`}>
                  Contact
                  <ChevronDown className="ml-1 h-4 w-4" />
                </DropdownMenuTrigger>
                <DropdownMenuContent className="bg-white border border-gray-200 shadow-lg z-[60] min-w-[200px]">
                  {contactDropdownItems.map((item) => (
                    <DropdownMenuItem key={item.href} asChild>
                      <Link
                        to={item.href}
                        className={`block px-4 py-2 text-sm hover:bg-gray-100 ${
                          location.pathname === item.href
                            ? 'text-accent font-medium'
                            : 'text-gray-700'
                        }`}
                      >
                        {item.label}
                      </Link>
                    </DropdownMenuItem>
                  ))}
                </DropdownMenuContent>
              </DropdownMenu>
            </div>
          </div>

          {/* Auth Button - Desktop */}
          <div className="hidden md:block">
            <AuthButton />
          </div>

          {/* Mobile menu button */}
          <div className="md:hidden">
            <button
              id="mobile-menu-button"
              onClick={() => setIsOpen(!isOpen)}
              className="inline-flex items-center justify-center p-2 rounded-md text-gray-700 hover:text-accent hover:bg-gray-100 focus:outline-none focus:ring-2 focus:ring-inset focus:ring-accent"
              aria-expanded="false"
            >
              <span className="sr-only">Open main menu</span>
              {isOpen ? (
                <X className="block h-6 w-6" aria-hidden="true" />
              ) : (
                <Menu className="block h-6 w-6" aria-hidden="true" />
              )}
            </button>
          </div>
        </div>
      </div>

      {/* Mobile Navigation Menu */}
      {isOpen && (
        <div id="mobile-menu" className="md:hidden">
          <div className="px-2 pt-2 pb-3 space-y-1 sm:px-3 bg-white border-t">
            {navItems.map((item) => (
              <Link
                key={item.href}
                to={item.href}
                onClick={item.onClick}
                className={`block px-3 py-2 rounded-md text-base font-medium transition-colors duration-200 ${
                  location.pathname === item.href
                    ? 'text-accent bg-accent/10'
                    : 'text-gray-700 hover:text-accent hover:bg-accent/5'
                }`}
              >
                {item.label}
              </Link>
            ))}
            
            {/* Mobile FAQ Section */}
            <div className="border-t border-gray-200 pt-2 mt-2">
              <div className="px-3 py-1 text-xs font-semibold text-gray-500 uppercase tracking-wider">
                FAQ
              </div>
              {faqDropdownItems.map((item) => (
                <Link
                  key={item.href}
                  to={item.href}
                  className={`block px-3 py-2 rounded-md text-base font-medium transition-colors duration-200 ${
                    location.pathname === item.href
                      ? 'text-accent bg-accent/10'
                      : 'text-gray-700 hover:text-accent hover:bg-accent/5'
                  }`}
                >
                  {item.label}
                </Link>
              ))}
            </div>
            
            {/* Mobile Contact Section */}
            <div className="border-t border-gray-200 pt-2 mt-2">
              <div className="px-3 py-1 text-xs font-semibold text-gray-500 uppercase tracking-wider">
                Contact
              </div>
              {contactDropdownItems.map((item) => (
                <Link
                  key={item.href}
                  to={item.href}
                  className={`block px-3 py-2 rounded-md text-base font-medium transition-colors duration-200 ${
                    location.pathname === item.href
                      ? 'text-accent bg-accent/10'
                      : 'text-gray-700 hover:text-accent hover:bg-accent/5'
                  }`}
                >
                  {item.label}
                </Link>
              ))}
            </div>
            
            <div className="px-3 py-2">
              <AuthButton />
            </div>
          </div>
        </div>
      )}
    </nav>
  );
};

export default Navigation;
